@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtCharts/QPieSeries>
 #include <private/qpieseries_p.h>
@@ -60,7 +34,7 @@ QT_BEGIN_NAMESPACE
     by setting a starting angle and angle span for the series.
     A full pie is 360 degrees, where 0 is at 12 a'clock.
 
-    See the \l {PieChart Example} {pie chart example} or \l {DonutChart Example} {donut chart example} to learn how to use QPieSeries.
+    See the \l {Charts with Widgets Gallery} to learn how to use QPieSeries.
     \image examples_piechart.png
     \image examples_donutchart.png
 
@@ -90,7 +64,7 @@ QT_BEGIN_NAMESPACE
 
     The following QML example shows how to create a simple pie chart.
 
-    \snippet qmlchart/qml/qmlchart/View1.qml 1
+    \snippet qmlchartsgallery/qml/PieChart.qml 1
 
     \beginfloatleft
     \image examples_qmlchart1.png
@@ -492,7 +466,7 @@ bool QPieSeries::append(const QList<QPieSlice *> &slices)
 {
     Q_D(QPieSeries);
 
-    if (slices.count() == 0)
+    if (slices.size() == 0)
         return false;
 
     for (auto *s : slices) {
@@ -566,7 +540,7 @@ bool QPieSeries::insert(int index, QPieSlice *slice)
 {
     Q_D(QPieSeries);
 
-    if (index < 0 || index > d->m_slices.count())
+    if (index < 0 || index > d->m_slices.size())
         return false;
 
     if (!slice || d->m_slices.contains(slice))
@@ -656,7 +630,7 @@ bool QPieSeries::take(QPieSlice *slice)
 void QPieSeries::clear()
 {
     Q_D(QPieSeries);
-    if (d->m_slices.count() == 0)
+    if (d->m_slices.size() == 0)
         return;
 
     QList<QPieSlice *> slices = d->m_slices;
@@ -687,7 +661,7 @@ QList<QPieSlice *> QPieSeries::slices() const
 int QPieSeries::count() const
 {
     Q_D(const QPieSeries);
-    return d->m_slices.count();
+    return d->m_slices.size();
 }
 
 /*!
@@ -1042,12 +1016,12 @@ void QPieSeriesPrivate::initializeTheme(int index, ChartTheme* theme, bool force
     //const QList<QColor>& colors = theme->seriesColors();
     const QList<QGradient>& gradients = theme->seriesGradients();
 
-    for (int i(0); i < m_slices.count(); i++) {
+    for (int i(0); i < m_slices.size(); i++) {
 
         QColor penColor = ChartThemeManager::colorAt(gradients.at(index % gradients.size()), 0.0);
 
         // Get color for a slice from a gradient linearly, beginning from the start of the gradient
-        qreal pos = (qreal)(i + 1) / (qreal) m_slices.count();
+        qreal pos = (qreal)(i + 1) / (qreal) m_slices.size();
         QColor brushColor = ChartThemeManager::colorAt(gradients.at(index % gradients.size()), pos);
 
         QPieSlice *s = m_slices.at(i);
